pinmyreqs
============

.. image:: https://img.shields.io/pypi/v/pinmyreqs.svg
    :target: https://pypi.python.org/pypi/pinmyreqs

*Pin your requirements.txt dependencies without adding new ones*

Usage:

To install, :code:`pip install pinmyreqs`

To use, :code:`pip freeze | pinmyreqs requirements.txt`

There's also an utility to unpin your deps so you can upgrade all of them:
:code:`unpinmyreqs requirements.txt`